pub struct ParseError {
pub id: Option<String>,
pub code: &'static str,
pub message: String,
}Expand description
Error parsing a single segment document, mapped to an
UnprocessedTraceSegment entry by the handler.
Fields
id: Option<String>The segment id, when it could be read from the malformed document.
code: &'static strmessage: StringTrait Implementations